@@ -5,13 +5,8 @@ import logging
 import mock
 import sys
 import unittest
-from gettext import gettext as _
 from mock import patch
 
-from UpdateManager.Dialogs import NoUpdatesDialog
-from UpdateManager.UpdateManager import UpdateManager
-from UpdateManager.UpdatesAvailable import UpdatesAvailable
-
 import os
 CURDIR = os.path.dirname(os.path.abspath(__file__))
 
