@@ -2,7 +2,6 @@
 # -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
 
 import logging
-import mock
 import sys
 import unittest
 from gettext import gettext as _
@@ -10,7 +9,6 @@ from mock import patch
 
 from UpdateManager.Dialogs import NoUpdatesDialog
 from UpdateManager.UpdateManager import UpdateManager
-from UpdateManager.backend import (InstallBackend, get_backend)
 from UpdateManager.UpdatesAvailable import UpdatesAvailable
 
 import os
